@@ -30,7 +30,7 @@ class WebAppState(LibraryComponent):
         self,
         key: str,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
         message: Optional[str] = None,
     ) -> Any:
         """Get saved data from the local storage.
@@ -134,7 +134,7 @@ class WebAppState(LibraryComponent):
         self,
         key: str,
         assertion_operator: Optional[AssertionOperator] = None,
-        assertion_expected: Any = None,
+        assertion_expected: Optional[Any] = None,
     ) -> Any:
         """Get saved data from from session storage.
 
